package com.chelvc.framework.oauth.interceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.base.model.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;
import org.springframework.http.HttpStatus;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestControllerAdvice;

/**
 * 安全异常处理拦截器
 *
 * @author Woody
 * @date 2023/1/1
 */
@Slf4j
@RestControllerAdvice
@Order(Ordered.HIGHEST_PRECEDENCE)
public class OauthExceptionInterceptor {
    /**
     * 认证异常转换
     *
     * @param response  请求响应对象
     * @param exception 异常对象
     * @return 请求结果
     */
    @ResponseStatus(HttpStatus.UNAUTHORIZED)
    @ExceptionHandler(BadCredentialsException.class)
    public Result<?> exception(HttpServletRequest request, HttpServletResponse response,
                               BadCredentialsException exception) {
        log.warn(SessionContextHolder.getLoggingMessage(request, HttpStatus.UNAUTHORIZED, exception));
        SessionContextHolder.initializeResponseWrappingHeader(response);
        return Result.build(HttpStatus.UNAUTHORIZED);
    }
}
