package com.chelvc.framework.rocketmq.consumer;

import com.chelvc.framework.rocketmq.annotation.RocketMQConsumer;
import com.chelvc.framework.rocketmq.config.RocketMQProperties;
import com.chelvc.framework.rocketmq.interceptor.RocketMQListener;
import org.apache.rocketmq.client.apis.ClientConfiguration;
import org.apache.rocketmq.client.apis.ClientServiceProvider;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.context.ApplicationContext;

/**
 * 消息监听器容器接口
 *
 * @param <T> 监听消息对象类型
 * @author Woody
 * @date 2023/1/1
 */
public interface RocketMQListenerContainer<T> extends DisposableBean {
    /**
     * 容器初始化
     *
     * @param provider           客户端服务生产者实例
     * @param configuration      客户端配置实例
     * @param applicationContext 应用上下文实例
     * @param listener           消息监听器实例
     * @param annotation         消息消费者注解实例
     * @param properties         消息配置属性
     */
    void initialize(ClientServiceProvider provider, ClientConfiguration configuration,
                    ApplicationContext applicationContext, RocketMQListener<T> listener, RocketMQConsumer annotation,
                    RocketMQProperties properties);
}
